@@ -15,3 +15,11 @@ class LoginRateThrottle(DefaultRateMixin, ScopedRateThrottle):
 
 class PasswordResetRateThrottle(DefaultRateMixin, ScopedRateThrottle):
     default_rate = '3/hour'
+
+    def allow_request(self, request, view):
+        if request.META['REQUEST_METHOD'] != 'POST':
+            return True
+        return super(PasswordResetRateThrottle, self).allow_request(
+            request,
+            view,
+        )
