@@ -34,15 +34,12 @@ settings.configure(
     AUTHENTICATION_BACKENDS = (
         'user_management.models.backends.CaseInsensitiveEmailBackend',
     ),
+    MIDDLEWARE_CLASSES = (),
     ROOT_URLCONF='user_management.api.tests.urls',
     REST_FRAMEWORK={
         'DEFAULT_AUTHENTICATION_CLASSES': (
             'rest_framework.authentication.TokenAuthentication',
         ),
-        'DEFAULT_THROTTLE_RATES': {
-            'logins': '100/day',
-            'passwords': '100/day',
-        }
     },
 )
 
